[Cdd-commits] r1044 - in cdd/trunk/webtools: . po webconf

CDD Subversion Commit noreply at alioth.debian.org
Tue Aug 26 14:17:55 UTC 2008


Author: tille
Date: Tue Aug 26 14:17:55 2008
New Revision: 1044

Added:
   cdd/trunk/webtools/distasktools.py   (contents, props changed)
      - copied, changed from r1042, cdd/trunk/webtools/cddtasktools.py
   cdd/trunk/webtools/po/dis-webtools.pot   (contents, props changed)
      - copied, changed from r1042, cdd/trunk/webtools/po/cdd-webtools.pot
Removed:
   cdd/trunk/webtools/cddtasktools.py
   cdd/trunk/webtools/po/cdd-webtools.pot
Modified:
   cdd/trunk/webtools/mkmo.sh
   cdd/trunk/webtools/mkpo.sh
   cdd/trunk/webtools/mkpot.sh
   cdd/trunk/webtools/po/cs.po
   cdd/trunk/webtools/po/da.po
   cdd/trunk/webtools/po/de.po
   cdd/trunk/webtools/po/es.po
   cdd/trunk/webtools/po/fi.po
   cdd/trunk/webtools/po/fr.po
   cdd/trunk/webtools/po/it.po
   cdd/trunk/webtools/po/ja.po
   cdd/trunk/webtools/po/ko.po
   cdd/trunk/webtools/po/nl.po
   cdd/trunk/webtools/po/php-message-strings.pot
   cdd/trunk/webtools/po/pl.po
   cdd/trunk/webtools/po/pt.po
   cdd/trunk/webtools/po/ru.po
   cdd/trunk/webtools/po/zh.po
   cdd/trunk/webtools/tasks.py
   cdd/trunk/webtools/update-all-tasks
   cdd/trunk/webtools/webconf/debian-edu.conf
   cdd/trunk/webtools/webconf/debian-gis.conf
   cdd/trunk/webtools/webconf/debian-junior.conf
   cdd/trunk/webtools/webconf/debian-med.conf
   cdd/trunk/webtools/webconf/debian-science.conf
Log:
s/Custom Debian Distribution/Debian Integrated Solution/


Copied: cdd/trunk/webtools/distasktools.py (from r1042, cdd/trunk/webtools/cddtasktools.py)
==============================================================================
--- cdd/trunk/webtools/mkmo.sh	(original)
+++ cdd/trunk/webtools/mkmo.sh	Tue Aug 26 14:17:55 2008
@@ -1,8 +1,6 @@
-#!/bin/sh
+#!/bin/sh -e
 
-set -e
-
-domain="cdd-webtools"
+domain="dis-webtools"
 podir="po"
 [ "--force" != "$1" ] || rm -rf "locale"
 ls -1 "$podir"/*.po | xargs -I{} basename '{}' .po | while read lang; do

Modified: cdd/trunk/webtools/mkpo.sh
==============================================================================
--- cdd/trunk/webtools/mkpo.sh	(original)
+++ cdd/trunk/webtools/mkpo.sh	Tue Aug 26 14:17:55 2008
@@ -1,5 +1,5 @@
 #!/bin/sh -e
-NAME=cdd-webtools
+NAME=dis-webtools
 TMPPOT=tmp.pot
 
 cd po

Modified: cdd/trunk/webtools/mkpot.sh
==============================================================================
--- cdd/trunk/webtools/mkpot.sh	(original)
+++ cdd/trunk/webtools/mkpot.sh	Tue Aug 26 14:17:55 2008
@@ -1,12 +1,12 @@
 #!/bin/sh
-NAME=cdd-webtools
+NAME=dis-webtools
 
 xgettext \
 	--default-domain="$NAME" \
 	--package-name="$NAME" \
 	--package-version="0.1.1" \
 	--msgid-bugs-address="debian-custom at lists.debian.org" \
-	--copyright-holder="Custom Debian Distribution Team <debian-custom at lists.debian.org>" \
+	--copyright-holder="Debian Integrated Solutions Team <debian-custom at lists.debian.org>" \
 	--keyword="_" \
 	--output-dir="po" \
 	--escape \

Modified: cdd/trunk/webtools/po/cs.po
==============================================================================
--- cdd/trunk/webtools/po/cs.po	(original)
+++ cdd/trunk/webtools/po/cs.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/da.po
==============================================================================
--- cdd/trunk/webtools/po/da.po	(original)
+++ cdd/trunk/webtools/po/da.po	Tue Aug 26 14:17:55 2008
@@ -1,11 +1,11 @@
 # SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR Custom Debian Distribution Team <debian-custom at lists.debian.org>
+# Copyright (C) YEAR Debian Integrated Solution Team <debian-custom at lists.debian.org>
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL at ADDRESS>, YEAR.
 #
 #, fuzzy
 msgid   ""
-msgstr  "Project-Id-Version: cdd-webtools 0.1.1\n"
+msgstr  "Project-Id-Version: dis-webtools 0.1.1\n"
         "Report-Msgid-Bugs-To: debian-custom at lists.debian.org\n"
         "POT-Creation-Date: 2008-07-09 07:42+0200\n"
         "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
@@ -78,7 +78,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -160,7 +160,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -290,7 +290,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -418,7 +418,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/de.po
==============================================================================
--- cdd/trunk/webtools/po/de.po	(original)
+++ cdd/trunk/webtools/po/de.po	Tue Aug 26 14:17:55 2008
@@ -81,11 +81,11 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  "Die Liste auf der rechten Seite enthält verschiedene Softwareprojekte, die für das %s "
         "Projekt von Interesse sind. Derzeit sind nur einige von diesen als Debianpakete "
         "verfügbar. Zielsetzung ist es jedoch, all die Software für %s zu paketieren, um einen "
-        "qualitativ hochwertigeCustom Debian Distribution (interne Anpassung von Debian an "
+        "qualitativ hochwertigeDebian Integrated Solution (interne Anpassung von Debian an "
         "spezielle Bedürfnisse) zu erstellen."
 
 #: tasks.py:97
@@ -170,11 +170,11 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
-msgstr  "Eine %sCustom Debian Distribution%s (angepaßte Debian Distribution) ist ein internes "
+msgstr  "Eine %sDebian Integrated Solution%s (angepaßte Debian Distribution) ist ein internes "
         "Debianprojekt, das einen Satz von Paketen zusammenstellt, der Nutzern hilft, bestimmte "
         "Aufgaben Ihrer Arbeit zu bewältigen.  Die Liste rechts zeigt Aufgaben, die durch %s "
         "zusammengestellt wurden."
@@ -306,7 +306,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -437,9 +437,9 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  "Es ist jedoch unser Ziel, diese Software in Debian-Med zu integrieren, um eine qualitativ "
-        "hochwertige Custom Debian Distribution zu erstellen."
+        "hochwertige Debian Integrated Solution zu erstellen."
 
 #: ../tasks.tmpl:31
 #, php-format

Copied: cdd/trunk/webtools/po/dis-webtools.pot (from r1042, cdd/trunk/webtools/po/cdd-webtools.pot)
==============================================================================
--- cdd/trunk/webtools/po/cdd-webtools.pot	(original)
+++ cdd/trunk/webtools/po/dis-webtools.pot	Tue Aug 26 14:17:55 2008
@@ -1,12 +1,12 @@
 # SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR Custom Debian Distribution Team <debian-custom at lists.debian.org>
+# Copyright (C) YEAR Debian Integrated Solution Team <debian-custom at lists.debian.org>
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL at ADDRESS>, YEAR.
 #
 #, fuzzy
 msgid ""
 msgstr ""
-"Project-Id-Version: cdd-webtools 0.1.1\n"
+"Project-Id-Version: dis-webtools 0.1.1\n"
 "Report-Msgid-Bugs-To: debian-custom at lists.debian.org\n"
 "POT-Creation-Date: 2008-07-09 07:42+0200\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
@@ -82,7 +82,7 @@
 "The list to the right includes various software projects which are of some "
 "interest to the %s Project. Currently, only a few of them are available as "
 "Debian packages. It is our goal, however, to include all software in %s "
-"which can sensibly add to a high quality Custom Debian Distribution."
+"which can sensibly add to a high quality Debian Integrated Solution."
 msgstr ""
 
 #: tasks.py:97
@@ -170,7 +170,7 @@
 #: tasks.py:132
 #, python-format
 msgid ""
-"A %sCustom Debian Distribution%s is a Debian internal project which "
+"A %sDebian Integrated Solution%s is a Debian internal project which "
 "assembles\n"
 "a set of packages that might help users to solve certain tasks of their "
 "work.  The list on\n"

Modified: cdd/trunk/webtools/po/es.po
==============================================================================
--- cdd/trunk/webtools/po/es.po	(original)
+++ cdd/trunk/webtools/po/es.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/fi.po
==============================================================================
--- cdd/trunk/webtools/po/fi.po	(original)
+++ cdd/trunk/webtools/po/fi.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/fr.po
==============================================================================
--- cdd/trunk/webtools/po/fr.po	(original)
+++ cdd/trunk/webtools/po/fr.po	Tue Aug 26 14:17:55 2008
@@ -83,7 +83,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -167,7 +167,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -298,7 +298,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -429,7 +429,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/it.po
==============================================================================
--- cdd/trunk/webtools/po/it.po	(original)
+++ cdd/trunk/webtools/po/it.po	Tue Aug 26 14:17:55 2008
@@ -86,12 +86,12 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
 msgid   "Tasks page"
-msgstr  "Tasks della CDD"
+msgstr  "Tasks della DIS"
 
 #: tasks.py:98
 msgid   "Project"
@@ -176,7 +176,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -312,8 +312,8 @@
 msgstr  "Progetto Traduzione Descrizioni Debian"
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
-msgstr  "Tasks della CDD"
+msgid   "Tasks of our DIS"
+msgstr  "Tasks della DIS"
 
 #: ../index.php:47
 msgid   "SVN repository"
@@ -443,9 +443,9 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  "È nostro obiettivo, comunque, includere in Debian-Med tutto il software che può "
-        "sensibilmente contribuire a una Custom Debian Distribution di qualità."
+        "sensibilmente contribuire a una Debian Integrated Solution di qualità."
 
 #: ../tasks.tmpl:31
 #, php-format

Modified: cdd/trunk/webtools/po/ja.po
==============================================================================
--- cdd/trunk/webtools/po/ja.po	(original)
+++ cdd/trunk/webtools/po/ja.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/ko.po
==============================================================================
--- cdd/trunk/webtools/po/ko.po	(original)
+++ cdd/trunk/webtools/po/ko.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/nl.po
==============================================================================
--- cdd/trunk/webtools/po/nl.po	(original)
+++ cdd/trunk/webtools/po/nl.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/php-message-strings.pot
==============================================================================
--- cdd/trunk/webtools/po/php-message-strings.pot	(original)
+++ cdd/trunk/webtools/po/php-message-strings.pot	Tue Aug 26 14:17:55 2008
@@ -105,7 +105,7 @@
 msgstr ""
 
 #: ../index.php:46
-msgid "Tasks of our CDD"
+msgid "Tasks of our DIS"
 msgstr ""
 
 #: ../index.php:47
@@ -230,7 +230,7 @@
 msgstr ""
 
 #: ../tasks.tmpl:20
-msgid "It is our goal, however, to include all software in Debian-Med which can sensibly add to a high quality Custom Debian Distribution."
+msgid "It is our goal, however, to include all software in Debian-Med which can sensibly add to a high quality Debian Integrated Solution."
 msgstr ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/pl.po
==============================================================================
--- cdd/trunk/webtools/po/pl.po	(original)
+++ cdd/trunk/webtools/po/pl.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/pt.po
==============================================================================
--- cdd/trunk/webtools/po/pt.po	(original)
+++ cdd/trunk/webtools/po/pt.po	Tue Aug 26 14:17:55 2008
@@ -83,7 +83,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -171,7 +171,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -307,7 +307,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -438,7 +438,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/ru.po
==============================================================================
--- cdd/trunk/webtools/po/ru.po	(original)
+++ cdd/trunk/webtools/po/ru.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/po/zh.po
==============================================================================
--- cdd/trunk/webtools/po/zh.po	(original)
+++ cdd/trunk/webtools/po/zh.po	Tue Aug 26 14:17:55 2008
@@ -61,7 +61,7 @@
 msgid   "The list to the right includes various software projects which are of some interest to "
         "the %s Project. Currently, only a few of them are available as Debian packages. It is our "
         "goal, however, to include all software in %s which can sensibly add to a high quality "
-        "Custom Debian Distribution."
+        "Debian Integrated Solution."
 msgstr  ""
 
 #: tasks.py:97
@@ -143,7 +143,7 @@
 
 #: tasks.py:132
 #, python-format
-msgid   "A %sCustom Debian Distribution%s is a Debian internal project which assembles\n"
+msgid   "A %sDebian Integrated Solution%s is a Debian internal project which assembles\n"
         "a set of packages that might help users to solve certain tasks of their work.  The list "
         "on\n"
         "the right shows the tasks of %s."
@@ -273,7 +273,7 @@
 msgstr  ""
 
 #: ../index.php:46
-msgid   "Tasks of our CDD"
+msgid   "Tasks of our DIS"
 msgstr  ""
 
 #: ../index.php:47
@@ -401,7 +401,7 @@
 
 #: ../tasks.tmpl:20
 msgid   "It is our goal, however, to include all software in Debian-Med which can sensibly add to "
-        "a high quality Custom Debian Distribution."
+        "a high quality Debian Integrated Solution."
 msgstr  ""
 
 #: ../tasks.tmpl:31

Modified: cdd/trunk/webtools/tasks.py
==============================================================================
--- cdd/trunk/webtools/tasks.py	(original)
+++ cdd/trunk/webtools/tasks.py	Tue Aug 26 14:17:55 2008
@@ -15,20 +15,20 @@
 from genshi.template import TemplateLoader
 from genshi import Markup
 
-from cddtasktools import CddDependencies, ReadConfig
+from distasktools import DisDependencies, ReadConfig
 
 languages = ('en', 'cs', 'da', 'de', 'es', 'fi', 'fr', 'it', 'ja', 'ko', 'nl', 'pl', 'pt_BR', 'ru', 'zh_CN')
 
 if len(argv) <= 1:
-	print >>stderr, "Usage: %s <CDD name>\n       The <CDD name> needs a matching config file webconf/<CDD name>.conf"\
+	print >>stderr, "Usage: %s <DIS name>\n       The <DIS name> needs a matching config file webconf/<DIS name>.conf"\
                         % argv[0]
 	exit(-1)
 
-cdeps=CddDependencies(argv[1])
+cdeps=DisDependencies(argv[1])
 cdeps.GetAllDependencies()
 packages     = cdeps.GetNamesOnlyDict()
 cdeps.GetTranslations(languages)
-cdeps.MarkupPreformatedStringsCDD()
+cdeps.MarkupPreformatedStringsDIS()
 
 data = cdeps.data
 data['tasks']            = cdeps.GetTaskDescDict()
@@ -43,7 +43,7 @@
 template_dir = os.path.join(current_dir, 'templates')
 
 # Initialize i18n
-domain = 'cdd-webtools'
+domain = 'dis-webtools'
 gettext.install(domain)
 l10nstring = {}
 for lang in languages:
@@ -93,7 +93,7 @@
                               to you, or if you have prepared an unofficial Debian package, please do not hesitate to
                               send a description of that project to the <a href="mailto:%s">%s mailing list</a>""") % \
                                   (data['projectname'], data['projectlist'], data['projectname']))
-        data['description']       = _("The list to the right includes various software projects which are of some interest to the %s Project. Currently, only a few of them are available as Debian packages. It is our goal, however, to include all software in %s which can sensibly add to a high quality Custom Debian Distribution.") % (data['projectname'], data['projectname'])
+        data['description']       = _("The list to the right includes various software projects which are of some interest to the %s Project. Currently, only a few of them are available as Debian packages. It is our goal, however, to include all software in %s which can sensibly add to a high quality Debian Integrated Solution.") % (data['projectname'], data['projectname'])
 	data['gtstrTasksPage']     = _('Tasks page')
 	data['gtstrProject']	   = _('Project')
 	data['gtstrThisIsAList']   = _('This is a list of the Tasks %s is made of:') % data['projectname']
@@ -131,10 +131,10 @@
                       prospective = _('Debian packages not available')
                     )
         data['packages']          = _('Packages')
-	data['idxsummary']        = _("""A %sCustom Debian Distribution%s is a Debian internal project which assembles
+	data['idxsummary']        = _("""A %sDebian Integrated Solution%s is a Debian internal project which assembles
 a set of packages that might help users to solve certain tasks of their work.  The list on
 the right shows the tasks of %s.""" ) \
-                                      % ('<a href="http://people.debian.org/~tille/cdd">', '</a>', data['projectname'])
+                                      % ('<a href="http://dis.alioth.debian.org/dis/">', '</a>', data['projectname'])
 	data['idxsummary']        = Markup(data['idxsummary'])
 
 	# Create the index page

Modified: cdd/trunk/webtools/update-all-tasks
==============================================================================
--- cdd/trunk/webtools/update-all-tasks	(original)
+++ cdd/trunk/webtools/update-all-tasks	Tue Aug 26 14:17:55 2008
@@ -1,6 +1,6 @@
 #!/bin/sh
 mkdir -p logs
-for cdd in `ls webconf/*.conf | sed 's?webconf/\(.*\)\.conf?\1?'` ; do
-    ./tasks.py $cdd 2> logs/${cdd}.err > logs/${cdd}.out
+for dis in `ls webconf/*.conf | sed 's?webconf/\(.*\)\.conf?\1?'` ; do
+    ./tasks.py $dis 2> logs/${dis}.err > logs/${dis}.out
 done
 

Modified: cdd/trunk/webtools/webconf/debian-edu.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-edu.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-edu.conf	Tue Aug 26 14:17:55 2008
@@ -1,4 +1,4 @@
-CDD:         debian-edu
+DIS:         debian-edu
 ProjectName: Debian Edu
 ProjectUrl:  http://debian-edu.alioth.debian.org/
 Homepage:    http://wiki.debian.org/DebianEdu

Modified: cdd/trunk/webtools/webconf/debian-gis.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-gis.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-gis.conf	Tue Aug 26 14:17:55 2008
@@ -1,4 +1,4 @@
-CDD:         debian-gis
+DIS:         debian-gis
 ProjectName: Debian GIS
 ProjectUrl:  http://pkg-grass.alioth.debian.org/
 Homepage:    http://wiki.debian.org/DebianGis

Modified: cdd/trunk/webtools/webconf/debian-junior.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-junior.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-junior.conf	Tue Aug 26 14:17:55 2008
@@ -1,4 +1,4 @@
-CDD:         debian-junior
+DIS:         debian-junior
 ProjectName: Debian Junior
 ProjectUrl:  http://cdd.alioth.debian.org/projects/debian-jr
 Homepage:    http://www.debian.org/devel/debian-jr

Modified: cdd/trunk/webtools/webconf/debian-med.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-med.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-med.conf	Tue Aug 26 14:17:55 2008
@@ -1,4 +1,4 @@
-CDD:         debian-med
+DIS:         debian-med
 ProjectName: Debian Med
 ProjectUrl:  http://debian-med.alioth.debian.org/
 Homepage:    http://www.debian.org/devel/debian-med

Modified: cdd/trunk/webtools/webconf/debian-science.conf
==============================================================================
--- cdd/trunk/webtools/webconf/debian-science.conf	(original)
+++ cdd/trunk/webtools/webconf/debian-science.conf	Tue Aug 26 14:17:55 2008
@@ -1,4 +1,4 @@
-CDD:         debian-science
+DIS:         debian-science
 ProjectName: Debian Science
 ProjectUrl:  http://wiki.debian.org/DebianScience
 Homepage:    http://wiki.debian.org/DebianScience



More information about the Cdd-commits mailing list
--- cdd/trunk/webtools/cddtasktools.py	(original)
+++ cdd/trunk/webtools/distasktools.py	Tue Aug 26 14:17:55 2008
@@ -2,7 +2,7 @@
 # Copyright 2008: Andreas Tille <tille at debian.org>
 # License: GPL
 
-# CDD Meta packages are listing a set of Dependencies
+# DIS Metapackages are listing a set of Dependencies
 # These might be fullfilled by the Debian package
 # set or not.
 #
@@ -30,7 +30,7 @@
 # SVNHOST  = 'svn+ssh://svn.debian.org'
 SVNHOST  = 'svn://svn.debian.org'
 KEYSTOIGNORE = ( 'Architecture', 'Comment', 'Leaf', 'NeedConfig', 'Note', 'Section', 'Needconfig', 'DontAvoid')
-GLOBALCACHE  = "/var/cache/cdd/"
+GLOBALCACHE  = "/var/cache/dis/"
 DDTPURL = "http://ddtp.debian.net/debian/dists/"
 DDTPDIR = "/i18n/Translation-"
 DDTPLISTS = ('etch', 'lenny', 'sid')
@@ -42,18 +42,18 @@
 
 HOMEPAGENONE = '#'
 
-def ReadConfig(cddname=''):
-    # Try to read config file CONFDIR/<cddname>.conf
-    conffile = CONFDIR + '/' + cddname + '.conf'
+def ReadConfig(disname=''):
+    # Try to read config file CONFDIR/<disname>.conf
+    conffile = CONFDIR + '/' + disname + '.conf'
     if not os.access(conffile, os.R_OK):
-        # if config file can not be found in local dir, try /etc/cdd/webconf as fallback
-        conffile_default = '/etc/cdd/webconf/' + cddname + '.conf'
+        # if config file can not be found in local dir, try /etc/dis/webconf as fallback
+        conffile_default = '/etc/dis/webconf/' + disname + '.conf'
         if not os.access(conffile_default, os.R_OK):
             print >>stderr, "Unable to open config file %s or %s." % (conffile, conffile_default)
             exit(-1)
         conffile = conffile_default
     f = open(conffile, 'r')
-    ret = { 'CDD'         : '',
+    ret = { 'DIS'         : '',
             'projectname' : '',
             'projecturl'  : '',
             'homepage'    : '',
@@ -63,11 +63,11 @@
             'css'         : '',
             'outputdir'   : '',
             'datadir'     : '',
-            'cachedir'    : '/var/lib/gforge/chroot/home/groups/cdd/cache',
+            'cachedir'    : '/var/lib/gforge/chroot/home/groups/dis/cache',
             'advertising' : None,  # headline with advertising string is optional
           }
     for stanza in deb822.Sources.iter_paragraphs(f, shared_storage=False):    
-        ret['CDD']         = stanza['cdd']          # short name of the project
+        ret['DIS']         = stanza['dis']          # short name of the project
         ret['projectname'] = stanza['projectname']  # Printed name of the project
         ret['projecturl']  = stanza['projecturl']   # Link to the developer page with dynamic content
                                                     # like for instance these tasks pages
@@ -81,8 +81,8 @@
         ret['outputdir']   = stanza['outputdir']    # Dir for storing output HTML files
         ret['datadir']     = stanza['datadir']      # Dir for storing SVN information about project
         ret['cachedir']    = stanza['cachedir']     # Cache for Package and DDTP files - could be common
-                                                    # for all CDDs that's why the default value makes sense
-        ret['vcsdir']      = stanza['vcsdir']       # Path to CDD information files at svn.debian.org
+                                                    # for all DISs that's why the default value makes sense
+        ret['vcsdir']      = stanza['vcsdir']       # Path to DIS information files at svn.debian.org
         if stanza.has_key('advertising'):
             # we have to remove the gettext _() call which was inserted into the config
             # file to enable easy input for config file editors - but the call has to
@@ -95,9 +95,9 @@
 
 
 def InitTasksFiles(data):
     # Obtain tasks files from SVN of a CDD
     # The specification of the repository containing the tasks files
     # of a CDD can be done in webconf/<CDD>.conf
 
     # tasks directory to obtain dependencies and debian/control to obtain meta
     # information like the metapackage prefix
@@ -164,8 +164,8 @@
     # Hold information about a program that is in dependency list
     # The 
 
-    def __init__(self, cddname=None, taskname=None):
-        self.cddname        = cddname  # CDD that includes the package in dependency list
+    def __init__(self, disname=None, taskname=None):
+        self.disname        = disname  # DIS that includes the package in dependency list
         self.taskname       = taskname # Task which includes the Dependency
         self.pkg            = None # Name of dependant package
         self.PrintedName    = None # Only for Meta package names - no use for a real dependant package
@@ -200,31 +200,31 @@
         # Sort according to package name
         return cmp(self.pkg, other.pkg)
 
-class CddDependencies:
+class DisDependencies:
     # Provide a list of depencencies defined in Metapackages
     # This class concerns _all_ tasks of a CDD and is the most
     # complete source of information.  If only a single task
-    # should be handled by a tool that uses cddtasktools
+    # should be handled by a tool that uses distasktools
     # probably the class TaskDependencies (see below) is
     # your friend
 
-    def __init__(self, cddname):
+    def __init__(self, disname):
 
         # This Instance of the Available class contains all
         # information about packages that are avialable in Debian
         # See below for more information about Available class
         global available
 
-        self.data            = ReadConfig(cddname)
-        self.cddname         = self.data['CDD']
+        self.data            = ReadConfig(disname)
+        self.disname         = self.data['DIS']
         self.tasksdir        = InitTasksFiles(self.data)
         self.tasks           = {} # Dictionary of TasksDependency objects
         self.metapackagekeys = []
         self.available       = available
         self.alldeps_in_main = [] # sorted string list of package names with all packages
                                   # relevant for a CDD that are in main Debian (for use in DDTP)
         self.alldeps_in_main_info = {} # complete dictionary with package information
                                   # with all packages relevant for a CDD that are in
                                   # main to easily feed DDTP translation into the structures
                                   # -->
                                   # self.alldeps_in_main = self.alldeps_in_main_info.keys().sort()
@@ -240,22 +240,22 @@
         if self.metapackagekeys == []:
             self._GetMetapackages()
 
-        # Obtain the prefix of the meta packages of the CDD using cdd-dev tools cdd_get_names
-        if os.access('/usr/share/cdd-dev/cdd-get-names', os.X_OK):
-            cdd_get_names = '/usr/share/cdd-dev/cdd-get-names'
-        elif os.access(os.getcwd() + '/cdd-get-names', os.X_OK):
-            cdd_get_names = os.getcwd() + '/cdd-get-names'
+        # Obtain the prefix of the meta packages of the DIS using dis-dev tools dis_get_names
+        if os.access('/usr/share/dis-dev/dis-get-names', os.X_OK):
+            dis_get_names = '/usr/share/dis-dev/dis-get-names'
+        elif os.access(os.getcwd() + '/dis-get-names', os.X_OK):
+            dis_get_names = os.getcwd() + '/dis-get-names'
         else:
-            print >>stderr, "Please either install package cdd-dev or install a copy of devtools/cdd-get-names in your working directory"
+            print >>stderr, "Please either install package dis-dev or install a copy of devtools/dis-get-names in your working directory"
             exit(-1)
 
         # The prefix is used to build the meta package name that belongs to the task
-        cmd = "cd %s; %s metapackageprefix" % (self.data['datadir'], cdd_get_names)
+        cmd = "cd %s; %s metapackageprefix" % (self.data['datadir'], dis_get_names)
         pipe = Popen(cmd, shell=True, stdout=PIPE).stdout
         prefix = pipe.read().strip() + '-'
         pipe.close()
         for task in self.metapackagekeys:
-            td = TaskDependencies(self.cddname, task=task, tasksdir=self.tasksdir, prefix=prefix)
+            td = TaskDependencies(self.disname, task=task, tasksdir=self.tasksdir, prefix=prefix)
             td.GetTaskDependencies()
             self.tasks[task] = td
 
@@ -299,10 +299,10 @@
         return ret
 
     def GetTaskDescDict(self):
         # Return dictionary with description information of all tasks of a CDD
         return self.tasks
 
-    def GetAllDependantPackagesOfCDD(self, dependencytypes=()):
+    def GetAllDependantPackagesOfDIS(self, dependencytypes=()):
         # David Paleino needs for his DDTP web tool a list of
         # all available Dependencies.
         # Here only those packages are returned that are in
@@ -337,7 +337,7 @@
         return self.alldeps_in_main
 
     def GetTranslations(self, languages=()):
         # Get DDTP translations for the package dependencies in a CDD
 
         if languages == ():
             return
@@ -357,7 +357,7 @@
         # Only main has DDTP translations
         component = 'main'
 
-        pks2translate = self.GetAllDependantPackagesOfCDD()
+        pks2translate = self.GetAllDependantPackagesOfDIS()
         for lang in languages:
             if lang == 'en':
                 continue
@@ -390,9 +390,9 @@
                        (errtxt, ddtpfile, lang)
                 os.unlink(file)
 
-    def MarkupPreformatedStringsCDD(self):
+    def MarkupPreformatedStringsDIS(self):
         # Genshi does not touch strings that are marked with "Markup()" - so just
         # mark the strings that are ready formatted for the whole CDD
         for task in self.metapackagekeys:
             tdeps = self.tasks[task]
             tdeps.MarkupPreformatedStrings()
@@ -400,10 +400,10 @@
 
 class TaskDependencies:
     # List of depencencies defined in one Metapackage
-    def __init__(self, cddname, task, tasksdir=None, prefix=''):
+    def __init__(self, disname, task, tasksdir=None, prefix=''):
 
-        self.data     = ReadConfig(cddname)
-        self.cddname  = self.data['CDD']
+        self.data     = ReadConfig(disname)
+        self.disname  = self.data['DIS']
         if tasksdir != None:
             self.tasksdir = tasksdir
         else:
@@ -425,10 +425,10 @@
         self.available = available
 
         # Main information for a task
-        self.metapkg             = DependantPackage(self.cddname, self.task)
+        self.metapkg             = DependantPackage(self.disname, self.task)
         self.metapkg.pkg         = prefix + task
 
         # If a CDD just bases on the meta package of an other CDD (this is the
         # case in Debian Science which bases on med-bio for biology and gis-workstation
         # for geography it makes no sense to build an own sentinel page but read
         # meta package information of other meta packages and include the content
@@ -484,7 +484,7 @@
 
                 if key in dep_strength_keys:
                     # Hack: Debian Edu tasks files are using '\' at EOL which is broken
                     #       in RFC 822 files, but cdd-gen-control from cdd-dev 0.5.x relies
                     #       on this.  So remove this stuff here for the Moment
                     dependencies = re.sub('\\\\\n\s+', '', stanza[key])
 
@@ -512,7 +512,7 @@
                             else:
                                 # print "Package %s actively ignored / avoided." % dep.pkg
                                 pass
-                        dep = DependantPackage(self.cddname, self.task)
+                        dep = DependantPackage(self.disname, self.task)
                         # Store the comments in case they might be usefull for later applications
                         dep.why            = why
                         dep.responsible    = responsible
@@ -95,9 +95,9 @@
 
 def InitTasksFiles(data):
-    # Obtain tasks files from SVN of a CDD
+    # Obtain tasks files from SVN of a DIS
     # The specification of the repository containing the tasks files
@@ -95,9 +95,9 @@
     # The specification of the repository containing the tasks files
-    # of a CDD can be done in webconf/<CDD>.conf
+    # of a DIS can be done in webconf/<DIS>.conf
 
     # tasks directory to obtain dependencies and debian/control to obtain meta
@@ -200,31 +200,31 @@
     # Provide a list of depencencies defined in Metapackages
-    # This class concerns _all_ tasks of a CDD and is the most
+    # This class concerns _all_ tasks of a DIS and is the most
     # complete source of information.  If only a single task
@@ -200,31 +200,31 @@
         self.available       = available
         self.alldeps_in_main = [] # sorted string list of package names with all packages
-                                  # relevant for a CDD that are in main Debian (for use in DDTP)
+                                  # relevant for a DIS that are in main Debian (for use in DDTP)
         self.alldeps_in_main_info = {} # complete dictionary with package information
@@ -200,31 +200,31 @@
         self.alldeps_in_main_info = {} # complete dictionary with package information
-                                  # with all packages relevant for a CDD that are in
+                                  # with all packages relevant for a DIS that are in
                                   # main to easily feed DDTP translation into the structures
                                   # -->
@@ -299,10 +299,10 @@
 
     def GetTaskDescDict(self):
-        # Return dictionary with description information of all tasks of a CDD
+        # Return dictionary with description information of all tasks of a DIS
         return self.tasks
 
@@ -337,7 +337,7 @@
 
     def GetTranslations(self, languages=()):
-        # Get DDTP translations for the package dependencies in a CDD
+        # Get DDTP translations for the package dependencies in a DIS
 
         if languages == ():
@@ -390,9 +390,9 @@
         # Genshi does not touch strings that are marked with "Markup()" - so just
-        # mark the strings that are ready formatted for the whole CDD
+        # mark the strings that are ready formatted for the whole DIS
         for task in self.metapackagekeys:
             tdeps = self.tasks[task]
@@ -425,10 +425,10 @@
         self.metapkg.pkg         = prefix + task
 
-        # If a CDD just bases on the meta package of an other CDD (this is the
+        # If a DIS just bases on the meta package of an other DIS (this is the
         # case in Debian Science which bases on med-bio for biology and gis-workstation
         # for geography it makes no sense to build an own sentinel page but read
@@ -484,7 +484,7 @@
                 if key in dep_strength_keys:
                     # Hack: Debian Edu tasks files are using '\' at EOL which is broken
-                    #       in RFC 822 files, but cdd-gen-control from cdd-dev 0.5.x relies
+                    #       in RFC 822 files, but dis-gen-control from dis-dev 0.5.x relies
                     #       on this.  So remove this stuff here for the Moment
                     dependencies = re.sub('\\\\\n\s+', '', stanza[key])

Modified: cdd/trunk/webtools/mkmo.sh
==============================================================================